==> libreoffice_4.3.7~rc2.orig.tar.xz: libreoffice-4.3.7~rc2/qadevOOo/tests/java/ifc/view/_XPrintSettingsSupplier.java <==
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

package ifc.view;

import lib.MultiMethodTest;

import com.sun.star.beans.XPropertySet;
import com.sun.star.view.XPrintSettingsSupplier;


/**
 * Testing <code>com.sun.star.view.XPrintSettingsSupplier</code>
 * interface methods :
 * <ul>
 *  <li><code> getPrintSettings()</code></li>
 * </ul> <p>
 * Test is <b> NOT </b> multithread compilant. <p>
 * @see com.sun.star.view.XPrintSettingsSupplier
 */
public class _XPrintSettingsSupplier extends MultiMethodTest {

    public XPrintSettingsSupplier oObj = null;

    /**
     * Test calls the method. <p>
     * Has <b> OK </b> status if the method returns not
     * <code>null</code> value.
     */
    public void _getPrintSettings(){

        XPropertySet oPSS = oObj.getPrintSettings();
        tRes.tested("getPrintSettings()", oPSS != null);

    } // finish _getPrintSettings

}  // finish class _XPrintSettingsSupplier

==> libreoffice-25.8.2.2.tar.xz: libreoffice-25.8.2.2/qadevOOo/tests/java/ifc/view/_XPrintSettingsSupplier.java <==
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

package ifc.view;

import lib.MultiMethodTest;

import com.sun.star.beans.XPropertySet;
import com.sun.star.view.XPrintSettingsSupplier;


/**
 * Testing <code>com.sun.star.view.XPrintSettingsSupplier</code>
 * interface methods :
 * <ul>
 *  <li><code> getPrintSettings()</code></li>
 * </ul> <p>
 * Test is <b> NOT </b> multithread compliant. <p>
 * @see com.sun.star.view.XPrintSettingsSupplier
 */
public class _XPrintSettingsSupplier extends MultiMethodTest {

    public XPrintSettingsSupplier oObj = null;

    /**
     * Test calls the method. <p>
     * Has <b> OK </b> status if the method returns not
     * <code>null</code> value.
     */
    public void _getPrintSettings(){

        XPropertySet oPSS = oObj.getPrintSettings();
        tRes.tested("getPrintSettings()", oPSS != null);

    } // finish _getPrintSettings

}  // finish class _XPrintSettingsSupplier
